@@ -5,8 +5,8 @@ File export.cpp
 /***************************************************************************
                                 FET
                           -------------------
-   copyright            : (C) by Lalescu Liviu
-    email                : Please see https://lalescu.ro/liviu/ for details about contacting Liviu Lalescu (in particular, you can find here the e-mail address)
+   copyright            : (C) by Liviu Lalescu
+    email                : Please see https://lalescu.ro/liviu/ for details about contacting Liviu Lalescu (in particular, you can find there the email address)
  ***************************************************************************
                           export.cpp  -  description
                              -------------------
@@ -515,7 +515,7 @@ bool Export::selectSeparatorAndTextQuote(QWidget* parent, QDialog* &newParent, Q
 	
 	QObject::connect(pb, SIGNAL(clicked()), &separatorsDialog, SLOT(accept()));
 	QObject::connect(cancelpb, SIGNAL(clicked()), &separatorsDialog, SLOT(reject()));
-		
+	
 	int w=separatorsDialog.sizeHint().width();
 	int h=separatorsDialog.sizeHint().height();
 	separatorsDialog.resize(w,h);
@@ -1019,7 +1019,7 @@ bool Export::exportCSVActivities(QString& lastWarnings, const QString& textquote
 			int repres=-1;
 	
 			for(int i=0; i<c->n_activities; i++){
-				int aid=c->activitiesId[i];
+				int aid=c->activitiesIds[i];
 				aset.insert(aid);
 	
 				if(activitiesRepresentant.value(aid,0)==aid)
@@ -1107,7 +1107,7 @@ bool Export::exportCSVActivities(QString& lastWarnings, const QString& textquote
 			int repres=-1;
 	
 			for(int i=0; i<c->n_activities; i++){
-				int aid=c->activitiesId[i];
+				int aid=c->activitiesIds[i];
 				aset.insert(aid);
 	
 				if(activitiesRepresentant.value(aid,0)==aid)
@@ -1213,7 +1213,7 @@ bool Export::exportCSVActivities(QString& lastWarnings, const QString& textquote
 				if(diffStudents)
 					s.append(tr("different students"));
 				if(diffCompNStud)
-					s.append(tr("different boolean variable 'must compute n total students'"));
+					s.append(tr("different Boolean variable 'must compute n total students'"));
 				if(diffNStud)
 					s.append(tr("different number of students"));
 				if(diffActive)
