@@ -6,8 +6,8 @@ File rules.h
                           rules.h  -  description
                              -------------------
     begin                : 2003
-    copyright            : (C) 2003 by Lalescu Liviu
-    email                : Please see https://lalescu.ro/liviu/ for details about contacting Liviu Lalescu (in particular, you can find here the e-mail address)
+    copyright            : (C) 2003 by Liviu Lalescu
+    email                : Please see https://lalescu.ro/liviu/ for details about contacting Liviu Lalescu (in particular, you can find there the email address)
  ***************************************************************************/
 
 /***************************************************************************
@@ -403,7 +403,7 @@ public:
 	*/
 	StudentsSet* searchStudentsSet(const QString& setName);
 	
-	StudentsSet* searchAugmentedStudentsSet(const QString& setName);
+	//StudentsSet* searchAugmentedStudentsSet(const QString& setName);
 	
 	/**
 	True if the students sets contain one common subgroup.
