@@ -3,7 +3,7 @@
 // Description: This file is part of FET
 //
 //
-// Author: Lalescu Liviu <Please see https://lalescu.ro/liviu/ for details about contacting Liviu Lalescu (in particular, you can find here the e-mail address)>
+// Author: Liviu Lalescu (Please see https://lalescu.ro/liviu/ for details about contacting Liviu Lalescu (in particular, you can find there the email address))
 // Copyright (C) 2005 Liviu Lalescu <https://lalescu.ro/liviu/>
 //
 /***************************************************************************
@@ -289,7 +289,7 @@ void ActivityTagsForm::activityTagChanged(int index)
 	}
 	
 	ActivityTag* st=gt.rules.activityTagsList.at(index);
-	assert(st);
+	assert(st!=nullptr);
 	QString s=st->getDetailedDescriptionWithConstraints(gt.rules);
 	currentActivityTagTextEdit->setPlainText(s);
 }
