@@ -2,8 +2,8 @@
                           addconstraintroomnotavailabletimesform.cpp  -  description
                              -------------------
     begin                : January 8, 2004
-    copyright            : (C) 2004 by Lalescu Liviu
-    email                : Please see https://lalescu.ro/liviu/ for details about contacting Liviu Lalescu (in particular, you can find here the e-mail address)
+    copyright            : (C) 2004 by Liviu Lalescu
+    email                : Please see https://lalescu.ro/liviu/ for details about contacting Liviu Lalescu (in particular, you can find there the email address)
  ***************************************************************************/
 
 /***************************************************************************
@@ -19,11 +19,6 @@
 
 #include <QMessageBox>
 
-#include "longtextmessagebox.h"
-
-#include "addconstraintroomnotavailabletimesform.h"
-#include "spaceconstraint.h"
-
 #include <QHeaderView>
 #include <QTableWidget>
 #include <QTableWidgetItem>
@@ -31,6 +26,10 @@
 #include <QBrush>
 #include <QColor>
 
+#include "longtextmessagebox.h"
+
+#include "addconstraintroomnotavailabletimesform.h"
+
 #define YES		(QString("X"))
 #define NO		(QString(" "))
 
