@@ -2,8 +2,8 @@
                           addconstraintteachersmaxbuildingchangesperdayform.cpp  -  description
                              -------------------
     begin                : Feb 10, 2005
-    copyright            : (C) 2005 by Lalescu Liviu
-    email                : Please see https://lalescu.ro/liviu/ for details about contacting Liviu Lalescu (in particular, you can find here the e-mail address)
+    copyright            : (C) 2005 by Liviu Lalescu
+    email                : Please see https://lalescu.ro/liviu/ for details about contacting Liviu Lalescu (in particular, you can find there the email address)
  ***************************************************************************/
 
 /***************************************************************************
@@ -20,7 +20,6 @@
 #include "longtextmessagebox.h"
 
 #include "addconstraintteachersmaxbuildingchangesperdayform.h"
-#include "spaceconstraint.h"
 
 AddConstraintTeachersMaxBuildingChangesPerDayForm::AddConstraintTeachersMaxBuildingChangesPerDayForm(QWidget* parent): QDialog(parent)
 {
