@@ -2,8 +2,8 @@
                           addgroupactivitiesininitialorderitemform.cpp  -  description
                              -------------------
     begin                : 2014
-    copyright            : (C) 2014 by Lalescu Liviu
-    email                : Please see https://lalescu.ro/liviu/ for details about contacting Liviu Lalescu (in particular, you can find here the e-mail address)
+    copyright            : (C) 2014 by Liviu Lalescu
+    email                : Please see https://lalescu.ro/liviu/ for details about contacting Liviu Lalescu (in particular, you can find there the email address)
  ***************************************************************************/
 
 /***************************************************************************
@@ -20,7 +20,6 @@
 #include "longtextmessagebox.h"
 
 #include "addgroupactivitiesininitialorderitemform.h"
-#include "spaceconstraint.h"
 
 #include <QListWidget>
 #include <QAbstractItemView>
@@ -178,6 +177,7 @@ void AddGroupActivitiesInInitialOrderItemForm::addItem()
 	
 	GroupActivitiesInInitialOrderItem* item=new GroupActivitiesInInitialOrderItem();
 	item->ids=ids;
+	item->recomputeActivitiesSet();
 	gt.rules.groupActivitiesInInitialOrderList.append(item);
 	
 	gt.rules.internalStructureComputed=false;
