@@ -2,8 +2,8 @@
                           allspaceconstraintsform.h  -  description
                              -------------------
     begin                : Feb 13, 2005
-    copyright            : (C) 2005 by Lalescu Liviu
-    email                : Please see https://lalescu.ro/liviu/ for details about contacting Liviu Lalescu (in particular, you can find here the e-mail address)
+    copyright            : (C) 2005 by Liviu Lalescu
+    email                : Please see https://lalescu.ro/liviu/ for details about contacting Liviu Lalescu (in particular, you can find there the email address)
  ***************************************************************************/
 
 /***************************************************************************
@@ -62,6 +62,8 @@ public slots:
 
 	void activateConstraint();
 	void deactivateConstraint();
+	void activateAllConstraints();
+	void deactivateAllConstraints();
 	void constraintComments();
 };
 
