@@ -2,8 +2,8 @@
                           constraintactivitiesnotoverlappingform.cpp  -  description
                              -------------------
     begin                : Feb 11, 2005
-    copyright            : (C) 2005 by Lalescu Liviu
-    email                : Please see https://lalescu.ro/liviu/ for details about contacting Liviu Lalescu (in particular, you can find here the e-mail address)
+    copyright            : (C) 2005 by Liviu Lalescu
+    email                : Please see https://lalescu.ro/liviu/ for details about contacting Liviu Lalescu (in particular, you can find there the email address)
  ***************************************************************************/
 
 /***************************************************************************
@@ -115,7 +115,7 @@ bool ConstraintActivitiesNotOverlappingForm::filterOk(TimeConstraint* ctr)
 	for(int i=0; i<c->n_activities; i++){
 		//bool found=true;
 	
-		int id=c->activitiesId[i];
+		int id=c->activitiesIds[i];
 		/*Activity* act=nullptr;
 		for(Activity* a : qAsConst(gt.rules.activitiesList))
 			if(a->id==id)
