@@ -2,8 +2,8 @@
                           constraintmingapsbetweenactivitiesform.cpp  -  description
                              -------------------
     begin                : July 10, 2008
-    copyright            : (C) 2008 by Lalescu Liviu
-    email                : Please see https://lalescu.ro/liviu/ for details about contacting Liviu Lalescu (in particular, you can find here the e-mail address)
+    copyright            : (C) 2008 by Liviu Lalescu
+    email                : Please see https://lalescu.ro/liviu/ for details about contacting Liviu Lalescu (in particular, you can find there the email address)
  ***************************************************************************/
 
 /***************************************************************************
@@ -116,7 +116,7 @@ bool ConstraintMinGapsBetweenActivitiesForm::filterOk(TimeConstraint* ctr)
 		
 	for(int i=0; i<c->n_activities; i++){
 	
-		int id=c->activitiesId[i];
+		int id=c->activitiesIds[i];
 		/*Activity* act=nullptr;
 		for(Activity* a : qAsConst(gt.rules.activitiesList))
 			if(a->id==id)
