@@ -3,7 +3,7 @@
 // Description: This file is part of FET
 //
 //
-// Author: Lalescu Liviu <Please see https://lalescu.ro/liviu/ for details about contacting Liviu Lalescu (in particular, you can find here the e-mail address)>
+// Author: Liviu Lalescu (Please see https://lalescu.ro/liviu/ for details about contacting Liviu Lalescu (in particular, you can find there the email address))
 // Copyright (C) 2003 Liviu Lalescu <https://lalescu.ro/liviu/>
 //
 /***************************************************************************
@@ -867,6 +867,9 @@ public slots:
 	void on_timetableUnlockActivitiesEndStudentsDayAction_triggered();
 	void on_timetableLockActivitiesWithASpecifiedActivityTagAction_triggered();
 	void on_timetableUnlockActivitiesWithASpecifiedActivityTagAction_triggered();
+	///
+	void on_timetableLockActivitiesWithAdvancedFilterAction_triggered();
+	void on_timetableUnlockActivitiesWithAdvancedFilterAction_triggered();
 
 	void on_timetableSaveTimetableAsAction_triggered();
 
