@@ -223,7 +223,7 @@ void HelpFaqForm::setText()
 	s+=tr("Q: Help on ConstraintMinDaysBetweenActivities.\n\n"
 		"A: It refers to a set of activities and involves a constant, N. For every pair of activities in the set, "
 		"it does not allow the distance (in days) between them to be less than N. If you specify N=1, then this "
-		"constraint means that no two activities can be scheduled in the same day. N=2 means that each two activities "
+		"constraint means that no two activities can be scheduled on the same day. N=2 means that each two activities "
 		"must be separated by at least one day\n\n"
 		"Example: 3 activities and N=2. Then, one can place them on Monday, Wednesday and Friday (5 days week).\n\n"
 		"Example2: 2 activities, N=3. Then, one can place them on Monday and Thursday, on Monday and Friday, then on Tuesday and Friday (5 days week).\n\n"
@@ -231,10 +231,11 @@ void HelpFaqForm::setText()
 		"because FET can detect impossible constraints this way and avoid them. The weight is subjective.\n\n"
 		"You can specify consecutive if same day. Please be careful, even if constraint min days between activities has 0% "
 		"weight, if you select this consecutive if same day, this consecutive will be forced. You will not be able to find "
-		"a timetable with the two activities in the same day, separated by break, not available or other activities, even "
-		"if the constraint has weight 0%, if you select consecutive if same day.\n\n"
-		"Currently FET can put at most 2 activities in the same day if 'consecutive if same day' is true. "
-		"FET cannot put 3 or more activities in the same day if 'consecutive if same day' is true.");
+		"a timetable with the two activities on the same day, separated by break, not available or other activities, even "
+		"if the constraint has weight 0%, if you select consecutive if same day.");
+	s+="\n\n";
+	s+=tr("Note: FET will not place more than two activities involved in this constraint on the same day, if the constraint is broken "
+		"(you may end up with more days containing two involved activities, though, if the constraint is to be broken more times).");
 	s+="\n\n";
 	s+=tr("Important: please do not input unnecessary duplicates. If you input for instance 2 constraints:\n\n"
 		"1. Activities 1 and 2, min days 1, consecutive if same day=true, weight=95%\n"
@@ -549,7 +550,7 @@ void HelpFaqForm::setText()
 		"subject, if they are on the same day. This constraint does that. If you want for instance to make teacher John to have "
 		"at least one gap between all his activities, select filter 'John' and add all his activities to a "
 		"constraint of this type. If you want to make teacher John to have at least one gap between all "
-		"his Math activities, select filter 'John' and 'Math' and add all these activities to a constraint of this type.\n\n"
+		"his math activities, select filter 'John' and 'math' and add all these activities to a constraint of this type.\n\n"
 		"Please take care that the selected activities are not forced consecutive by constraint two activities consecutive or "
 		"by constraint min days between activities which have consecutive if same day selected.");
 
@@ -629,10 +630,10 @@ void HelpFaqForm::setText()
 	s+="\n\n";
 	
 	s+=tr("Q: I have a double duration activity. Is it possible that it is spread over the break period, like:\n\n"
-		"Activity Math, duration 2, id say 100\n\n"
-		"Hour 10:00 Math (first hour of act. 100)\n"
-		"Hour 11:00 Break\n"
-		"Hour 12:00 Math (second hour of act. 100)?\n\n"
+		"Activity math, duration 2, id say 100\n\n"
+		"Hour 10:00 math (first hour of act. 100)\n"
+		"Hour 11:00 break\n"
+		"Hour 12:00 math (second hour of act. 100)?\n\n"
 		"A: No, the activity must respect the break, so it is before or after the break with all the hours of it.");
 	s+=" ";
 	s+=tr("Alternative solutions: either you can split that activity into two subactivities with duration 1 (without a min days constraint "
@@ -661,7 +662,7 @@ void HelpFaqForm::setText()
 	s+="--------------------";
 	s+="\n\n";
 
-	s+=tr("Q: I want to define hard subjects (Math, Physics and Chemistry) and I want students not to have more than 1 (or another variant 2) difficult subjects in a row.\n\n"
+	s+=tr("Q: I want to define hard subjects (math, physics and chemistry) and I want students not to have more than 1 (or another variant 2) difficult subjects in a row.\n\n"
 		"A: Define activity tag 'Difficult' and add it to all MA, PH and CH lessons. Then add constraint maximum 1 (or 2) "
 		"hours continuously for all students and an activity tag 'Difficult'. Please take care if you may have double lessons.");
 
@@ -688,7 +689,7 @@ void HelpFaqForm::setText()
 	s+=tr("Q: (by %1) The students must have max 4 gaps per week, maximum 2 per day, continuous gaps. How to solve this?\n\n"
 		"A: Add for each subgroup a dummy activity (no teachers) split into 4 per week, duration 1, min days between "
 		"activities 1, weight 0%, select consecutive if same day. FET will never put more than 2 of these dummy activities "
-		"in a day. Add max gaps for students = 0 per week.", "%1 is a person").arg(QString::fromUtf8("Horațiu Hălmăjan"));
+		"on a day. Add max gaps for students = 0 per week.", "%1 is a person").arg(QString::fromUtf8("Horațiu Hălmăjan"));
 
 	s+="\n\n";
 	s+="--------------------";
@@ -702,9 +703,9 @@ void HelpFaqForm::setText()
 	s+="\n\n";
 
 	s+=tr("Question 1/16 August 2009: How to add constraint two activities grouped, two activities consecutive and three "
-		"activities grouped if the activities are constrained not to be in the same day by constraints min days between activities?\n\n"
-		"If A1 and A2 are constrained not to be in the same day with 95% weight or any other weight, it is a bad practice "
-		"to add a constraint grouped or consecutive to them. If they are constrained with weight 100% not to be in the "
+		"activities grouped if the activities are constrained not to be on the same day by constraints min days between activities?\n\n"
+		"If A1 and A2 are constrained not to be on the same day with 95% weight or any other weight, it is a bad practice "
+		"to add a constraint grouped or consecutive to them. If they are constrained with weight 100% not to be on the "
 		"same day, the timetable is impossible; if the weight is under 100%, the timetable is more difficult to find than "
 		"using the correct way.\n\n"
 		"The correct way would probably be to consider A1 and A2 = a single activity A12', or to modify the related constraint "
@@ -750,20 +751,19 @@ void HelpFaqForm::setText()
 	s+="--------------------";
 	s+="\n\n";
 	
-	s+=tr("3 hints from an anonymous Polish user, who uses FET for very large data:");
+	s+=tr("Three hints from an anonymous Polish user, who uses FET for very large data sets:");
 	s+="\n\n";
-	s+=tr("The first hint for other users is to start with minimum number of constraints and if FET would generate "
-		"the plan then thinking about adding the next ones.");
+	s+=tr("The first hint for other users is to start with a minimum number of constraints and see if FET can generate a timetable "
+		"with those constraints before thinking about adding the next ones.");
 	s+="\n\n";
-	s+=tr("The second hint is not to change too many constraints in one simulation as it may lead to impossible timetable "
-		"and then it is difficult to say which particular constraint was too much.");
+	s+=tr("The second hint is not to change too many constraints in one simulation. If it is impossible to generate a timetable with those added constraints, "
+		"it is difficult to say which particular constraint was responsible.");
 	s+="\n\n";
-	s+=tr("For instance even when two consecutive activities are placed at one day "
-		"(the same group and the same teacher) sometimes they are placed at different rooms what would force them to needless "
-		"changing room. I guess that FET is focused on fulfilling constraints but not on optimizing timetable. Sometimes "
-		"simple changing of two activities makes plan better both for students and teachers. I think that manually improving "
-		"generated plan is faster than creating many many more constraints and repeating simulations. And this is the third hint.");
-
+	s+=tr("It may happen, for example, that even when two consecutive activities are placed on the same day (with the same group and the same teacher) "
+		"sometimes they are placed in different rooms, which would force them to needlessly change rooms. I guess that FET is focused on fulfilling constraints "
+		"but not on optimizing timetables. Sometimes simply changing the two activities is better both for the students and the teachers. I think that manually "
+		"improving a generated timetable is faster than creating many more constraints and repeating simulations. And this is the third hint.");
+	
 	s+="\n\n";
 	s+="--------------------";
 	s+="\n\n";
@@ -870,8 +870,8 @@ void HelpFaqForm::setText()
 	s+="--------------------";
 	s+="\n\n";
 
-	s+=tr("Q: I need to add a split activity with total duration 4, which can be either 2+2 or 2+1+1 (two hours in a day and two hours in another day,"
-		" or two hours in a day, one hour in another day and one hour in another day).");
+	s+=tr("Q: I need to add a split activity with total duration 4, which can be either 2+2 or 2+1+1 (two hours on a day and two hours on another day,"
+		" or two hours on a day, one hour on another day and one hour on another day).");
 	s+="\n\n";
 	s+=tr("A: Add 3 activities (let us assume that their id-s are 1, 2 and 3), with durations respectively 2, 1 and 1. It is preferable to add them as"
 		" 3 single/independent activities (see note below).\n\n"
@@ -1000,7 +1000,7 @@ void HelpFaqForm::setText()
 	s+=" ";
 	s+=tr("(Also the conflicts timetable might take long to write, if the file is large.)");
 	s+=" ";
-	s+=tr("After that, you can re-enable writing of the timetables and re-generate.");
+	s+=tr("After that, you can enable the writing of the timetables and regenerate.");
 
 	s+="\n\n";
 	s+="--------------------";
