@@ -2,8 +2,8 @@
                           modifyconstraintactivitiesoccupymaxdifferentroomsform.cpp  -  description
                              -------------------
     begin                : Apr 29, 2012
-    copyright            : (C) 2012 by Lalescu Liviu
-    email                : Please see https://lalescu.ro/liviu/ for details about contacting Liviu Lalescu (in particular, you can find here the e-mail address)
+    copyright            : (C) 2012 by Liviu Lalescu
+    email                : Please see https://lalescu.ro/liviu/ for details about contacting Liviu Lalescu (in particular, you can find there the email address)
  ***************************************************************************/
 
 /***************************************************************************
@@ -20,7 +20,6 @@
 #include "longtextmessagebox.h"
 
 #include "modifyconstraintactivitiesoccupymaxdifferentroomsform.h"
-#include "spaceconstraint.h"
 
 #include <QListWidget>
 #include <QAbstractItemView>
@@ -121,12 +120,6 @@ void ModifyConstraintActivitiesOccupyMaxDifferentRoomsForm::ok()
 		return;
 	}
 	
-	this->_ctr->weightPercentage=weight;
-
-	int maxDifferentRooms=maxDifferentRoomsSpinBox->value();
-	
-	this->_ctr->maxDifferentRooms=maxDifferentRooms;
-
 	if(this->selectedActivitiesList.count()==0){
 		QMessageBox::warning(this, tr("FET information"),
 		 tr("Empty list of activities"));
@@ -138,7 +131,14 @@ void ModifyConstraintActivitiesOccupyMaxDifferentRoomsForm::ok()
 		return;
 	}
 	
+	this->_ctr->weightPercentage=weight;
+
+	int maxDifferentRooms=maxDifferentRoomsSpinBox->value();
+	
+	this->_ctr->maxDifferentRooms=maxDifferentRooms;
+
 	this->_ctr->activitiesIds=selectedActivitiesList;
+	this->_ctr->recomputeActivitiesSet();
 	
 	gt.rules.internalStructureComputed=false;
 	setRulesModifiedAndOtherThings(&gt.rules);
