@@ -2,8 +2,8 @@
                           modifyconstraintactivitiessameroomifconsecutiveform.cpp  -  description
                              -------------------
     begin                : Sept 14, 2013
-    copyright            : (C) 2013 by Lalescu Liviu
-    email                : Please see https://lalescu.ro/liviu/ for details about contacting Liviu Lalescu (in particular, you can find here the e-mail address)
+    copyright            : (C) 2013 by Liviu Lalescu
+    email                : Please see https://lalescu.ro/liviu/ for details about contacting Liviu Lalescu (in particular, you can find there the email address)
  ***************************************************************************/
 
 /***************************************************************************
@@ -17,15 +17,14 @@
 
 #include <QMessageBox>
 
-#include "longtextmessagebox.h"
-
-#include "modifyconstraintactivitiessameroomifconsecutiveform.h"
-#include "spaceconstraint.h"
-
 #include <QListWidget>
 #include <QAbstractItemView>
 #include <QScrollBar>
 
+#include "longtextmessagebox.h"
+
+#include "modifyconstraintactivitiessameroomifconsecutiveform.h"
+
 ModifyConstraintActivitiesSameRoomIfConsecutiveForm::ModifyConstraintActivitiesSameRoomIfConsecutiveForm(QWidget* parent, ConstraintActivitiesSameRoomIfConsecutive* ctr): QDialog(parent)
 {
 	setupUi(this);
@@ -117,8 +116,6 @@ void ModifyConstraintActivitiesSameRoomIfConsecutiveForm::ok()
 		return;
 	}
 	
-	this->_ctr->weightPercentage=weight;
-
 	if(this->selectedActivitiesList.count()==0){
 		QMessageBox::warning(this, tr("FET information"),
 		 tr("Empty list of activities"));
@@ -130,7 +127,10 @@ void ModifyConstraintActivitiesSameRoomIfConsecutiveForm::ok()
 		return;
 	}
 	
+	this->_ctr->weightPercentage=weight;
+
 	this->_ctr->activitiesIds=selectedActivitiesList;
+	this->_ctr->recomputeActivitiesSet();
 	
 	gt.rules.internalStructureComputed=false;
 	setRulesModifiedAndOtherThings(&gt.rules);
