@@ -2,8 +2,8 @@
                           modifyconstraintactivitiessamestartingtimeform.cpp  -  description
                              -------------------
     begin                : Feb 11, 2005
-    copyright            : (C) 2005 by Lalescu Liviu
-    email                : Please see https://lalescu.ro/liviu/ for details about contacting Liviu Lalescu (in particular, you can find here the e-mail address)
+    copyright            : (C) 2005 by Liviu Lalescu
+    email                : Please see https://lalescu.ro/liviu/ for details about contacting Liviu Lalescu (in particular, you can find there the email address)
  ***************************************************************************/
 
 /***************************************************************************
@@ -62,7 +62,7 @@ ModifyConstraintActivitiesSameStartingTimeForm::ModifyConstraintActivitiesSameSt
 	this->selectedActivitiesList.clear();
 	
 	for(int i=0; i<ctr->n_activities; i++){
-		int actId=ctr->activitiesId[i];
+		int actId=ctr->activitiesIds[i];
 		this->selectedActivitiesList.append(actId);
 		Activity *act=gt.rules.activitiesPointerHash.value(actId, nullptr);
 		assert(act!=nullptr);
@@ -190,12 +190,13 @@ void ModifyConstraintActivitiesSameStartingTimeForm::ok()
 	
 	int i;
 	QList<int>::const_iterator it;
-	this->_ctr->activitiesId.clear();
+	this->_ctr->activitiesIds.clear();
 	for(i=0, it=this->selectedActivitiesList.constBegin(); it!=this->selectedActivitiesList.constEnd(); it++, i++){
-		this->_ctr->activitiesId.append(*it);
+		this->_ctr->activitiesIds.append(*it);
 	}
 	this->_ctr->n_activities=i;
-		
+	this->_ctr->recomputeActivitiesSet();
+	
 	this->_ctr->weightPercentage=weight;
 	
 	gt.rules.internalStructureComputed=false;
