@@ -2,8 +2,8 @@
                           modifyconstraintactivitytagpreferredroomsform.cpp  -  description
                              -------------------
     begin                : 2009
-    copyright            : (C) 2009 by Lalescu Liviu
-    email                : Please see https://lalescu.ro/liviu/ for details about contacting Liviu Lalescu (in particular, you can find here the e-mail address)
+    copyright            : (C) 2009 by Liviu Lalescu
+    email                : Please see https://lalescu.ro/liviu/ for details about contacting Liviu Lalescu (in particular, you can find there the email address)
  ***************************************************************************/
 
 /***************************************************************************
@@ -17,12 +17,11 @@
 
 #include <QMessageBox>
 
-#include "modifyconstraintactivitytagpreferredroomsform.h"
-#include "spaceconstraint.h"
-
 #include <QListWidget>
 #include <QAbstractItemView>
 
+#include "modifyconstraintactivitytagpreferredroomsform.h"
+
 ModifyConstraintActivityTagPreferredRoomsForm::ModifyConstraintActivityTagPreferredRoomsForm(QWidget* parent, ConstraintActivityTagPreferredRooms* ctr): QDialog(parent)
 {
 	setupUi(this);
