@@ -2,8 +2,8 @@
                           modifyconstraintmindaysbetweenactivitiesform.cpp  -  description
                              -------------------
     begin                : Feb 11, 2005
-    copyright            : (C) 2005 by Lalescu Liviu
-    email                : Please see https://lalescu.ro/liviu/ for details about contacting Liviu Lalescu (in particular, you can find here the e-mail address)
+    copyright            : (C) 2005 by Liviu Lalescu
+    email                : Please see https://lalescu.ro/liviu/ for details about contacting Liviu Lalescu (in particular, you can find there the email address)
  ***************************************************************************/
 
 /***************************************************************************
@@ -17,15 +17,14 @@
 
 #include <QMessageBox>
 
-#include "modifyconstraintmindaysbetweenactivitiesform.h"
-#include "spaceconstraint.h"
-
 #include <QList>
 
 #include <QListWidget>
 #include <QAbstractItemView>
 #include <QScrollBar>
 
+#include "modifyconstraintmindaysbetweenactivitiesform.h"
+
 ModifyConstraintMinDaysBetweenActivitiesForm::ModifyConstraintMinDaysBetweenActivitiesForm(QWidget* parent, ConstraintMinDaysBetweenActivities* ctr): QDialog(parent)
 {
 	setupUi(this);
@@ -60,7 +59,7 @@ ModifyConstraintMinDaysBetweenActivitiesForm::ModifyConstraintMinDaysBetweenActi
 	selectedActivitiesList.clear();
 	selectedActivitiesListWidget->clear();
 	for(int i=0; i<ctr->n_activities; i++){
-		int actId=ctr->activitiesId[i];
+		int actId=ctr->activitiesIds[i];
 		this->selectedActivitiesList.append(actId);
 		Activity *act=gt.rules.activitiesPointerHash.value(actId, nullptr);
 		assert(act!=nullptr);
@@ -242,9 +241,9 @@ void ModifyConstraintMinDaysBetweenActivitiesForm::ok()
 
 		int i;
 		QList<int>::const_iterator it;
-		adc.activitiesId.clear();
+		adc.activitiesIds.clear();
 		for(i=0, it=this->selectedActivitiesList.constBegin(); it!=this->selectedActivitiesList.constEnd(); it++, i++){
-			adc.activitiesId.append(*it);
+			adc.activitiesIds.append(*it);
 		}
 		adc.n_activities=i;
 		
@@ -260,15 +259,15 @@ void ModifyConstraintMinDaysBetweenActivitiesForm::ok()
 					duplicate=true;
 					break;
 				}
-				
+		
 		if(duplicate){
 			QMessageBox::warning(this, tr("FET information"), tr("Cannot proceed, current constraint is equal to another one (it is duplicated)"));
 			return;
 		}
 	}
 	
-	if(_ctr->activitiesId!=selectedActivitiesList){
-		for(int oldId : qAsConst(_ctr->activitiesId)){
+	if(_ctr->activitiesIds!=selectedActivitiesList){
+		for(int oldId : qAsConst(_ctr->activitiesIds)){
 			QSet<ConstraintMinDaysBetweenActivities*> cs=gt.rules.mdbaHash.value(oldId, QSet<ConstraintMinDaysBetweenActivities*>());
 			assert(cs.contains(_ctr));
 			cs.remove(_ctr);
@@ -282,18 +281,20 @@ void ModifyConstraintMinDaysBetweenActivitiesForm::ok()
 			gt.rules.mdbaHash.insert(newId, cs);
 		}
 		
-		_ctr->activitiesId=selectedActivitiesList;
-		_ctr->n_activities=_ctr->activitiesId.count();
+		_ctr->activitiesIds=selectedActivitiesList;
+		_ctr->n_activities=_ctr->activitiesIds.count();
+		_ctr->recomputeActivitiesSet();
 	}
 
 	/*int i;
 	QList<int>::iterator it;
-	this->_ctr->activitiesId.clear();
+	this->_ctr->activitiesIds.clear();
 	for(i=0, it=this->selectedActivitiesList.begin(); it!=this->selectedActivitiesList.end(); it++, i++){
-		this->_ctr->activitiesId.append(*it);
+		this->_ctr->activitiesIds.append(*it);
 	}
-	this->_ctr->n_activities=i;*/
-		
+	this->_ctr->n_activities=i;
+	this->_ctr->recomputeActivitiesSet();*/
+	
 	this->_ctr->weightPercentage=weight;
 	this->_ctr->consecutiveIfSameDay=consecutiveIfSameDayCheckBox->isChecked();
 	this->_ctr->minDays=minDaysSpinBox->value();
