@@ -2,8 +2,8 @@
                           modifyconstraintstudentsmaxroomchangesperdayform.cpp  -  description
                              -------------------
     begin                : 2019
-    copyright            : (C) 2019 by Lalescu Liviu
-    email                : Please see https://lalescu.ro/liviu/ for details about contacting Liviu Lalescu (in particular, you can find here the e-mail address)
+    copyright            : (C) 2019 by Liviu Lalescu
+    email                : Please see https://lalescu.ro/liviu/ for details about contacting Liviu Lalescu (in particular, you can find there the email address)
  ***************************************************************************/
 
 /***************************************************************************
@@ -18,7 +18,6 @@
 #include <QMessageBox>
 
 #include "modifyconstraintstudentsmaxroomchangesperdayform.h"
-#include "spaceconstraint.h"
 
 ModifyConstraintStudentsMaxRoomChangesPerDayForm::ModifyConstraintStudentsMaxRoomChangesPerDayForm(QWidget* parent, ConstraintStudentsMaxRoomChangesPerDay* ctr): QDialog(parent)
 {
