@@ -25,7 +25,6 @@
 
 #include "timetable.h"
 #include "timetable_defs.h"
-//#include "timetableexport.h"		//TODO: remove?!
 
 #include "longtextmessagebox.h"
 
@@ -177,7 +176,7 @@ StatisticsPrintForm::StatisticsPrintForm(QWidget *parent): QDialog(parent){
 	CBBreak->setSizePolicy(QSizePolicy::Expanding, CBBreak->sizePolicy().verticalPolicy());
 	
 	QStringList whiteSpaceStrings;
-	whiteSpaceStrings<<QString("normal")<<QString("pre")<<QString("nowrap")<<QString("pre-wrap");	//don't translate these strings, because they are css parameters!
+	whiteSpaceStrings<<QString("normal")<<QString("pre")<<QString("nowrap")<<QString("pre-wrap");	//don't translate these strings, because they are CSS parameters!
 	CBWhiteSpace=new QComboBox();
 	CBWhiteSpace->addItems(whiteSpaceStrings);
 	CBWhiteSpace->setCurrentIndex(0);
@@ -562,7 +561,7 @@ StatisticsPrintForm::StatisticsPrintForm(QWidget *parent): QDialog(parent){
 	restoreFETDialogGeometry(this);
 	
 	QSettings settings(COMPANY, PROGRAM);
-		
+	
 	if(settings.contains(this->metaObject()->className()+studentSubjectRBState))
 		studentSubjectRB->setChecked(settings.value(this->metaObject()->className()+studentSubjectRBState).toBool());
 	if(settings.contains(this->metaObject()->className()+studentTeacherRBState))
@@ -586,8 +585,8 @@ StatisticsPrintForm::StatisticsPrintForm(QWidget *parent): QDialog(parent){
 		CBpaperSize->setCurrentIndex(settings.value(this->metaObject()->className()+CBpaperSizeState).toInt());
 	if(settings.contains(this->metaObject()->className()+CBorientationModeState))
 		CBorientationMode->setCurrentIndex(settings.value(this->metaObject()->className()+CBorientationModeState).toInt());
-//	if(settings.contains(this->metaObject()->className()+printDetailedTablesState))
-//		printDetailedTables->setChecked(settings.value(this->metaObject()->className()+printDetailedTablesState).toBool());
+	//if(settings.contains(this->metaObject()->className()+printDetailedTablesState))
+	//	printDetailedTables->setChecked(settings.value(this->metaObject()->className()+printDetailedTablesState).toBool());
 	if(settings.contains(this->metaObject()->className()+printActivityTagsState))
 		printActivityTags->setChecked(settings.value(this->metaObject()->className()+printActivityTagsState).toBool());
 	//
@@ -810,7 +809,7 @@ QString StatisticsPrintForm::updateHTMLprintString(bool printAll){
 	if(studentSubjectRB->isChecked()){
 		int count=0;
 		while(excludedNamesIndex.size()<namesList->count()){
-			tmp+=StatisticsExport::exportStatisticsStudentsSubjectsHtml(NULL/*parent*/, saveTime, statisticValues, 3, printActivityTags->isChecked(), maxNames->value(), &excludedNamesIndex);
+			tmp+=StatisticsExport::exportStatisticsStudentsSubjectsHtml(nullptr/*parent*/, saveTime, statisticValues, 3, printActivityTags->isChecked(), maxNames->value(), &excludedNamesIndex);
 			if(excludedNamesIndex.size()<namesList->count()){
 				if(count%2==0){
 					tmp+="    <p class=\"back1\"><br /></p>\n\n";
@@ -825,7 +824,7 @@ QString StatisticsPrintForm::updateHTMLprintString(bool printAll){
 	if(studentTeacherRB->isChecked()){
 		int count=0;
 		while(excludedNamesIndex.size()<namesList->count()){
-			tmp+=StatisticsExport::exportStatisticsStudentsTeachersHtml(NULL/*parent*/, saveTime, statisticValues, 3, printActivityTags->isChecked(), maxNames->value(), &excludedNamesIndex);
+			tmp+=StatisticsExport::exportStatisticsStudentsTeachersHtml(nullptr/*parent*/, saveTime, statisticValues, 3, printActivityTags->isChecked(), maxNames->value(), &excludedNamesIndex);
 			if(excludedNamesIndex.size()<namesList->count()){
 				if(count%2==0){
 					tmp+="    <p class=\"back1\"><br /></p>\n\n";
@@ -840,7 +839,7 @@ QString StatisticsPrintForm::updateHTMLprintString(bool printAll){
 	if(teacherSubjectRB->isChecked()){
 		int count=0;
 		while(excludedNamesIndex.size()<namesList->count()){
-			tmp+=StatisticsExport::exportStatisticsTeachersSubjectsHtml(NULL/*parent*/, saveTime, statisticValues, 3, printActivityTags->isChecked(), maxNames->value(), &excludedNamesIndex);
+			tmp+=StatisticsExport::exportStatisticsTeachersSubjectsHtml(nullptr/*parent*/, saveTime, statisticValues, 3, printActivityTags->isChecked(), maxNames->value(), &excludedNamesIndex);
 			if(excludedNamesIndex.size()<namesList->count()){
 				if(count%2==0){
 					tmp+="    <p class=\"back1\"><br /></p>\n\n";
@@ -855,7 +854,7 @@ QString StatisticsPrintForm::updateHTMLprintString(bool printAll){
 	if(teacherStudentRB->isChecked()){
 		int count=0;
 		while(excludedNamesIndex.size()<namesList->count()){
-			tmp+=StatisticsExport::exportStatisticsTeachersStudentsHtml(NULL/*parent*/, saveTime, statisticValues, 3, printActivityTags->isChecked(), maxNames->value(), &excludedNamesIndex);
+			tmp+=StatisticsExport::exportStatisticsTeachersStudentsHtml(nullptr/*parent*/, saveTime, statisticValues, 3, printActivityTags->isChecked(), maxNames->value(), &excludedNamesIndex);
 			if(excludedNamesIndex.size()<namesList->count()){
 				if(count%2==0){
 					tmp+="    <p class=\"back1\"><br /></p>\n\n";
@@ -870,7 +869,7 @@ QString StatisticsPrintForm::updateHTMLprintString(bool printAll){
 	if(subjectStudentRB->isChecked()){
 		int count=0;
 		while(excludedNamesIndex.size()<namesList->count()){
-			tmp+=StatisticsExport::exportStatisticsSubjectsStudentsHtml(NULL/*parent*/, saveTime, statisticValues, 3, printActivityTags->isChecked(), maxNames->value(), &excludedNamesIndex);
+			tmp+=StatisticsExport::exportStatisticsSubjectsStudentsHtml(nullptr/*parent*/, saveTime, statisticValues, 3, printActivityTags->isChecked(), maxNames->value(), &excludedNamesIndex);
 			if(excludedNamesIndex.size()<namesList->count()){
 				if(count%2==0){
 					tmp+="    <p class=\"back1\"><br /></p>\n\n";
@@ -885,7 +884,7 @@ QString StatisticsPrintForm::updateHTMLprintString(bool printAll){
 	if(subjectTeacherRB->isChecked()){
 		int count=0;
 		while(excludedNamesIndex.size()<namesList->count()){
-			tmp+=StatisticsExport::exportStatisticsSubjectsTeachersHtml(NULL/*parent*/, saveTime, statisticValues, 3, printActivityTags->isChecked(), maxNames->value(), &excludedNamesIndex);
+			tmp+=StatisticsExport::exportStatisticsSubjectsTeachersHtml(nullptr/*parent*/, saveTime, statisticValues, 3, printActivityTags->isChecked(), maxNames->value(), &excludedNamesIndex);
 			if(excludedNamesIndex.size()<namesList->count()){
 				if(count%2==0){
 					tmp+="    <p class=\"back1\"><br /></p>\n\n";
@@ -951,6 +950,10 @@ void StatisticsPrintForm::print(){
 	//QPrintDialog *printDialog = new QPrintDialog(&printer, this);
 	QPrintDialog printDialog(&printer, this);
 	printDialog.setWindowTitle(tr("Print statistics"));
+	
+	//const QString settingsName=QString("StatisticsPrintFormPrintDialog");
+	//restoreFETDialogGeometry(&printDialog, settingsName);
+	
 	if (printDialog.exec() == QDialog::Accepted) {
 		QTextDocument textDocument;
 		textDocument.documentLayout()->setPaintDevice(&printer);
@@ -962,6 +965,7 @@ void StatisticsPrintForm::print(){
 		textDocument.setHtml(updateHTMLprintString(true));
 		textDocument.print(&printer);
 	}
+	//saveFETDialogGeometry(&printDialog, settingsName);
 	//delete printDialog;
 #endif
 }
@@ -1007,7 +1011,13 @@ void StatisticsPrintForm::printPreviewFull(){
 #endif
 	QPrintPreviewDialog printPreviewFull(&printer, this);
 	connect(&printPreviewFull, SIGNAL(paintRequested(QPrinter*)), SLOT(updatePreviewFull(QPrinter*)));
+
+	const QString settingsName=QString("StatisticsPrintFormPrintPreviewFullDialog");
+	restoreFETDialogGeometry(&printPreviewFull, settingsName);
+
 	printPreviewFull.exec();
+
+	saveFETDialogGeometry(&printPreviewFull, settingsName);
 #endif
 }
 
@@ -1070,7 +1080,13 @@ void StatisticsPrintForm::printPreviewSmall(){
 #endif
 	QPrintPreviewDialog printPreviewSmall(&printer, this);
 	connect(&printPreviewSmall, SIGNAL(paintRequested(QPrinter*)), SLOT(updatePreviewSmall(QPrinter*)));
+
+	const QString settingsName=QString("StatisticsPrintFormPrintPreviewSmallDialog");
+	restoreFETDialogGeometry(&printPreviewSmall, settingsName);
+
 	printPreviewSmall.exec();
+
+	saveFETDialogGeometry(&printPreviewSmall, settingsName);
 #endif
 }
 
