@@ -2,8 +2,8 @@
                           subactivitiesform.h  -  description
                              -------------------
     begin                : 2009
-    copyright            : (C) 2009 by Lalescu Liviu
-    email                : Please see https://lalescu.ro/liviu/ for details about contacting Liviu Lalescu (in particular, you can find here the e-mail address)
+    copyright            : (C) 2009 by Liviu Lalescu
+    email                : Please see https://lalescu.ro/liviu/ for details about contacting Liviu Lalescu (in particular, you can find there the email address)
  ***************************************************************************/
 
 /***************************************************************************
@@ -22,6 +22,8 @@
 
 #include "activity.h"
 
+#include "advancedfilterform.h"
+
 #include <QSet>
 #include <QString>
 
@@ -31,6 +33,21 @@ class SubactivitiesForm : public QDialog, Ui::SubactivitiesForm_template  {
 private:
 	QSet<QString> showedStudents;
 	
+	AdvancedFilterForm* filterForm;
+
+	bool all; //all or any, true means all, false means any
+	QList<int> descrDetDescrDetDescrWithConstraints;
+	QList<int> contains;
+	QStringList text;
+	bool caseSensitive;
+	
+	bool useFilter;
+	
+	int NA;
+	int NT;
+	int DA;
+	int DT;
+
 public:
 	ActivitiesList visibleSubactivitiesList;
 
@@ -43,10 +60,17 @@ public slots:
 	void modifySubactivity();
 	void subactivityChanged();
 	void filterChanged();
+
+	void filter(bool active);
 	
 	void studentsFilterChanged();
 	
 	void help();
+
+	void activateSubactivity();
+	void deactivateSubactivity();
+	void activateAllSubactivities();
+	void deactivateAllSubactivities();
 	
 	void subactivityComments();
 };
