@@ -3,7 +3,7 @@
 // Description: This file is part of FET
 //
 //
-// Author: Lalescu Liviu <Please see https://lalescu.ro/liviu/ for details about contacting Liviu Lalescu (in particular, you can find here the e-mail address)>
+// Author: Liviu Lalescu (Please see https://lalescu.ro/liviu/ for details about contacting Liviu Lalescu (in particular, you can find there the email address))
 // Copyright (C) 2003 Liviu Lalescu <https://lalescu.ro/liviu/>
 //
 /***************************************************************************
@@ -284,7 +284,7 @@ void SubjectsForm::subjectChanged(int index)
 	}
 	
 	Subject* sb=gt.rules.subjectsList.at(index);
-	assert(sb);
+	assert(sb!=nullptr);
 	QString s=sb->getDetailedDescriptionWithConstraints(gt.rules);
 	currentSubjectTextEdit->setPlainText(s);
 }
