@@ -3,7 +3,7 @@
 // Description: This file is part of FET
 //
 //
-// Author: Lalescu Liviu <Please see https://lalescu.ro/liviu/ for details about contacting Liviu Lalescu (in particular, you can find here the e-mail address)>
+// Author: Liviu Lalescu (Please see https://lalescu.ro/liviu/ for details about contacting Liviu Lalescu (in particular, you can find there the email address))
 // Copyright (C) 2003 Liviu Lalescu <https://lalescu.ro/liviu/>
 //
 /***************************************************************************
@@ -381,7 +381,7 @@ void TeachersForm::teacherChanged(int index)
 	}
 	
 	Teacher* t=gt.rules.teachersList.at(index);
-	assert(t);
+	assert(t!=nullptr);
 	QString s=t->getDetailedDescriptionWithConstraints(gt.rules);
 	currentTeacherTextEdit->setPlainText(s);
 }
