@@ -2,8 +2,8 @@
                           teachersubjectsqualificationsform.cpp  -  description
                              -------------------
     begin                : 2016
-    copyright            : (C) 2016 by Lalescu Liviu
-    email                : Please see https://lalescu.ro/liviu/ for details about contacting Liviu Lalescu (in particular, you can find here the e-mail address)
+    copyright            : (C) 2016 by Liviu Lalescu
+    email                : Please see https://lalescu.ro/liviu/ for details about contacting Liviu Lalescu (in particular, you can find there the email address)
  ***************************************************************************/
 
 /***************************************************************************
@@ -20,7 +20,6 @@
 #include "longtextmessagebox.h"
 
 #include "teachersubjectsqualificationsform.h"
-#include "spaceconstraint.h"
 #include "teacher.h"
 
 #include <QListWidget>
