@@ -2,8 +2,8 @@
                           timetablegenerateform.cpp  -  description
                              -------------------
     begin                : Tue Apr 22 2003
-    copyright            : (C) 2003 by Lalescu Liviu
-    email                : Please see https://lalescu.ro/liviu/ for details about contacting Liviu Lalescu (in particular, you can find here the e-mail address)
+    copyright            : (C) 2003 by Liviu Lalescu
+    email                : Please see https://lalescu.ro/liviu/ for details about contacting Liviu Lalescu (in particular, you can find there the email address)
  ***************************************************************************/
 
 /***************************************************************************
@@ -176,7 +176,7 @@ void TimetableGenerateForm::start(){
 		return;
 	}
 
-	currentResultsTextEdit->setPlainText(TimetableGenerateForm::tr("Entering simulation....precomputing, please be patient"));
+	currentResultsTextEdit->setPlainText(TimetableGenerateForm::tr("Entering simulation ... precomputing, please be patient"));
 
 	gen.abortOptimization=false;
 	bool ok=gen.precompute(this);
